package com.muyu.common.core.enums;

import lombok.Getter;

import java.util.Arrays;

/**
 * 支付方式
 *
 * @author muyu
 */
@Getter
public enum SysPayType {
    ALI_PAY("alipay", "支付宝"),
    WEIXIN_PAY("weixinpay", "微信"),
    JD_PAY("jdpay", "京东");

    private final String code;
    private final String info;

    SysPayType(String code, String info) {
        this.code = code;
        this.info = info;
    }

    /**
     * 鉴别参数是否是启用状态
     * @param code 需鉴别参数
     * @return 如果存在返回结果turn,否则返回false
     */
    public static boolean isCode(String code){
        return Arrays.stream(values())
                .map(SysPayType::getCode)
                .anyMatch(c -> c.equals(code));
    }

    /**
     * 参数转换,从支付方式编码转换为支付方式名称
     * @param code 支付方式编码
     * @return 支付方式名称
     */
    public static String getInfoByCode(String code){
        return Arrays.stream(values())
                .filter(c -> c.getCode().equals(code))
                .findFirst()
                .map(SysPayType::getInfo)
                .orElse("-");
    }

    /**
     * 参数转换,从支付方式名称转换为支付方式编码
     * @param info 支付方式名称
     * @return 支付方式编码
     */
    public static String getCodeByInfo(String info){
        return Arrays.stream(values())
                .filter(c -> c.getInfo().equals(info))
                .findFirst()
                .map(SysPayType::getCode)
                .orElse("-");
    }
}
